Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7)

Unified Diff: include/core/SkCanvas.h

Issue 1657333002: Fix for rounded-rect clips with filters. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: picture GM fix Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gm/complexclip_blur_tiled.cpp ('k') | src/core/SkCanvas.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/core/SkCanvas.h
diff --git a/include/core/SkCanvas.h b/include/core/SkCanvas.h
index 2812b32856a082a9913882c276fe4a3d102a2c95..4ad915c641294e84f99c1ddad2b451de2967c888 100644
--- a/include/core/SkCanvas.h
+++ b/include/core/SkCanvas.h
@@ -1379,11 +1379,10 @@ private:
SkBaseDevice* init(SkBaseDevice*, InitFlags);
/**
* Gets the size/origin of the top level layer in global canvas coordinates. We don't want this
* to be public because it exposes decisions about layer sizes that are internal to the canvas.
*/
- SkISize getTopLayerSize() const;
- SkIPoint getTopLayerOrigin() const;
+ SkIRect getTopLayerBounds() const;
void internalDrawBitmapRect(const SkBitmap& bitmap, const SkRect* src,
const SkRect& dst, const SkPaint* paint,
« no previous file with comments | « gm/complexclip_blur_tiled.cpp ('k') | src/core/SkCanvas.cpp » ('j') | no next file with comments »
@@ -1379,11 +1379,10 @@ private:
SkBaseDevice* init(SkBaseDevice*, InitFlags);
/**
- * Gets the size/origin of the top level layer in global canvas coordinates. We don't want this
+ * Gets the bounds of the top level layer in global canvas coordinates. We don't want this
* to be public because it exposes decisions about layer sizes that are internal to the canvas.
*/

Powered by Google App Engine
This is Rietveld 408576698